#!/bin/sh
# ###############################################################
# Exceed onDemand Client 6
# Copyright (c) 1997-2006 Hummingbird Ltd. All Rights Reserved.
# ###############################################################
# desktop_integration_install.sh
# Installs desktop menu entry and .eod mime-type association
# $Revision: 7613 $
# ###############################################################

# --- Functions ---

try()
{
	cmd="$*"
	eval "$cmd"
	errorcode=$?
	if [ $errorcode != 0 ]; then
		echo "Desktop Integration command failed:" >&2
		echo "   Error code: $errorcode" >&2
		echo "   Command: '$cmd'" >&2
		return $errorcode
	fi
}

# -----------------

cde_settings()
{

if [ `whoami` = "root" ]; then 
               mode="system"
         dt_app_dir="/etc/dt/appconfig/appmanager/C/Desktop_Apps"
    dt_app_dir_root="/etc/dt/appconfig/appmanager/C"
     dt_app_usr_dir="/usr/dt/appconfig/appmanager/C/Desktop_Apps"
       dt_types_dir="/etc/dt/appconfig/types/C"
       dt_icons_dir="/etc/dt/appconfig/icons/C"
else
            mode="user"
      dt_app_dir=~/.dt/appmanager/Desktop_Apps
 dt_app_dir_root=~/.dt/appmanager
  dt_app_usr_dir="/usr/dt/appconfig/appmanager/C/Desktop_Apps"
    dt_types_dir=~/.dt/types
    dt_icons_dir=~/.dt/icons
fi

dt_eodname="Exceed_onDemand"
dt_actionfile="$dt_types_dir/$dt_eodname.dt"
dt_frontpanelfile="$dt_types_dir/$dt_eodname.fp"
dt_applinkfile="$dt_app_dir/$dt_eodname"
}

# -----------------

cde_reloadactions()
{
# if we're running CDE then make our changes show up now

dtaction_cmd="dtaction"
for cmd in \
  /usr/dt/bin/dtaction \
  `which dtaction`
do 
	[ -x "$cmd" ] && dtaction_cmd="$cmd"
done

have_dtaction=
[ -x "$dtaction_cmd" ] && have_dtaction=y


xlsatoms_cmd="xlsatoms"
for cmd in \
  /usr/bin/X11/xlsatoms \
  /usr/openwin/bin/xlsatoms \
  `which xlsatoms`
do 
	[ -x "$cmd" ] && xlsatoms_cmd="$cmd"
done

running_cde=`$xlsatoms_cmd 2>/dev/null | grep _DT_WM_READY`

if [ -n "$have_dtaction" ] && [ -n "$running_cde" ]; then
  try "$dtaction_cmd" ReloadActions
fi
}

# -----------------

cde_install()
{

cde_settings

# ------- Install Icons

[ ! -d "$dt_icons_dir" ] && try mkdir -p "$dt_icons_dir"
try cp "$thisdir/$dt_eodname*.[bp]m" "$dt_icons_dir"

# ------- Create Action and Data Type
# (.dt file, specifying command, icon, description, .eod association, etc.)

[ ! -d "$dt_types_dir" ] && try mkdir -p "$dt_types_dir"
cat > "$dt_actionfile" << __END_DTFILE__
#
# Exceed onDemand Client action and type information for CDE
#

DATA_ATTRIBUTES Eod
{
	DESCRIPTION Exceed onDemand Connection Document
	ICON        $dt_eodname
	ACTIONS     Open
	MIME_TYPE   application/x-exceedondemand
	IS_TEXT     true
}

DATA_CRITERIA Eod_Criteria
{
	DATA_ATTRIBUTES_NAME Eod
	NAME_PATTERN *.eod
	CONTENT 0 string [EODCONNECTION]
}

ACTION $dt_eodname
{
	LABEL       Exceed onDemand Client 6
	TYPE        COMMAND
	ICON        $dt_eodname
	WINDOW_TYPE NO_STDIO
	EXEC_STRING "$eodxc" %Arg_1%
	DESCRIPTION Connect to remote X applications and desktops
}

ACTION Open
{
	ARG_TYPE   Eod
	TYPE       MAP
	MAP_ACTION $dt_eodname
}
__END_DTFILE__

# add EoD link to main panel's "Personal Applications" subpanel
cat > $dt_frontpanelfile << __END_FPFILE__
CONTROL Exceed_onDemand
{
	LABEL          Exceed onDemand Client 6
	TYPE           file
	CONTAINER_TYPE SUBPANEL
	CONTAINER_NAME PersAppsSubpanel
	POSITION_HINTS last
	ICON           $dt_eodname
	FILE_NAME      $dt_applinkfile
	HELP_STRING Connect to remote X applications and desktops
}
__END_FPFILE__

# -------- Create Application Link --------
# (an empty executable file, connecting action .dt file to a menu)

# /etc/dt or ~/.dt appmanager directories override /usr without including it,
# so if we're creating a group that already exists we must make sure it
# starts off equal to /usr, before we add eod
[ ! -d "$dt_app_dir" ] && cp -r "$dt_app_usr_dir" "$dt_app_dir_root"
# if for some reason the copy failed then make an empty dir
[ ! -d "$dt_app_dir" ] && mkdir -p "$dt_app_dir"

echo "# $dt_eodname application link file" > "$dt_applinkfile"
chmod +x "$dt_applinkfile"


# make our changes show up without having to re-login
cde_reloadactions

}

# -----------------

xdg_install()
{

# install icons
try xdg-icon-resource install --size 48 ${eod_name}.png $eod_name
try xdg-icon-resource install --context mimetypes --size 48 ${eod_mime_type_dashed}.png $eod_mime_type_dashed

# install menu entry
sed -e "s|#EODXC#|$eodxc|" \
    -e "s|#ICON#|$absrootdir/setup/${eod_name}.png|" \
    ${eod_desktop_file}.in > /tmp/$eod_desktop_file
try xdg-desktop-menu install /tmp/$eod_desktop_file
try rm -f /tmp/$eod_desktop_file

# install mime-type association
try xdg-mime install $eod_mime_file
try xdg-mime default $eod_desktop_file $eod_mime_type

}

# -----------------

install()
{
absrootdir="`cd $thisdir/..; pwd`"
eodxc="${absrootdir}/eodxc"
[ -x "$eodxc" ] || echo "Warning: $eodxc is not found or executable." >&2

[ "$support_cde" = "true" ] && cde_install
[ "$support_xdg" = "true" ] && xdg_install
}

# -----------------

cde_uninstall()
{
cde_settings

for f in \
  $dt_icons_dir/$dt_eodname*.[bp]m \
  "$dt_actionfile" \
  "$dt_frontpanelfile" \
  "$dt_applinkfile"
do
  [ -e "$f" ] && try rm -f "$f"
done

# make our changes show up without having to re-login
cde_reloadactions

}

# -----------------

xdg_uninstall()
{
try xdg-icon-resource uninstall --size 48 ${eod_name}
try xdg-icon-resource uninstall --context mimetypes --size 48 $eod_mime_type_dashed
try xdg-desktop-menu uninstall $eod_desktop_file
try xdg-mime uninstall $eod_mime_file
}

# -----------------

uninstall()
{
[ "$support_cde" = "true" ] && cde_uninstall
[ "$support_xdg" = "true" ] && xdg_uninstall
}

# --- Settings ---

savedir=`pwd`
mydirname=`dirname $0`
thisdir=`cd $mydirname; pwd`

# xdg means KDE/Gnome/Xfce support
support_xdg="true"
# cde is only enabled on AIX for now
support_cde="false"
if [ `uname` = "AIX" ]; then
	support_cde=true
fi

# prefer system-installed xdg-utils; use ours only as a fallback
PATH=$PATH:$thisdir
export PATH

eod_name=hummingbird-exceedondemand
eod_icon_name=${eod_name}
eod_mime_file=${eod_name}.xml
eod_desktop_file=${eod_name}.desktop
eod_mime_type=application/x-exceedondemand
eod_mime_type_dashed=application-x-exceedondemand

# --- Main ---

try cd $thisdir || exit 1

if [ "$1" = "uninstall" ]; then
	uninstall
else
	install
fi

try cd $savedir
